@@ -12,7 +12,7 @@ from scipy.constants import physical_constants
 from scipy.integrate import simps
 from ase.geometry import get_distances
 
-from pyiron import Project
+from pyiron_atomistics import Project
 from pyiron_atomistics.atomistics.job.interactive import GenericInteractive
 from pyiron_atomistics.lammps.lammps import LammpsInteractive
 from pyiron_contrib.protocol.generic import PrimitiveVertex
@@ -1554,4 +1554,4 @@ class ComputeFormationEnergy(PrimitiveVertex):
             'formation_energy_mean': float(unumpy.nominal_values(fe)),
             'formation_energy_std': float(unumpy.std_devs(fe)),
             'formation_energy_se': float(unumpy.std_devs(fe_se))
-        }
\ No newline at end of file
+        }
